/*
 * Copyright 2008 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.derquinsej;

import java.util.Locale;

/**
 * Utility methods for Locales.
 * @author Andres Rodriguez
 */
public final class Locales {
	/**
	 * Not instantiable.
	 */
	private Locales() {
		throw new AssertionError();
	}
	
	private static String clean(String string) {
		if (string == null || string.length() == 0) {
			return null;
		}
		return string;
	}
	
	public static Locale getParent(Locale locale) {
		if ( locale == null ) {
			return null;
		}
		final String lang = clean(locale.getLanguage());
		final String country = clean(locale.getCountry());
		final String variant = clean(locale.getVariant());
		if ( variant != null ) {
			if ( country != null ) {
				return new Locale(lang, country);
			} else {
				return new Locale(lang);
			}
		} else if (country != null) {
			return new Locale(lang);
		}
		return null;
	}
	
}
